=== modified file 'bzrlib/option.py'
--- bzrlib/option.py	2009-03-23 14:59:43 +0000
+++ bzrlib/option.py	2009-04-03 20:05:25 +0000
@@ -150,7 +150,8 @@
     OPTIONS = {}
 
     def __init__(self, name, help='', type=None, argname=None,
-                 short_name=None, param_name=None, custom_callback=None):
+                 short_name=None, param_name=None, custom_callback=None,
+                 hidden=False):
         """Make a new command option.
 
         :param name: regular name of the command, used in the double-dash
@@ -173,6 +174,8 @@
         :param custom_callback: a callback routine to be called after normal
             processing. The signature of the callback routine is
             (option, name, new_value, parser).
+        :param hidden: If True, the option should be hidden in help and
+            documentation.
         """
         self.name = name
         self.help = help
@@ -189,6 +192,7 @@
         else:
             self._param_name = param_name
         self.custom_callback = custom_callback
+        self.hidden = hidden
 
     def short_name(self):
         if self._short_name:
@@ -208,12 +212,16 @@
         option_strings = ['--%s' % self.name]
         if short_name is not None:
             option_strings.append('-%s' % short_name)
+        if self.hidden:
+            help = optparse.SUPPRESS_HELP
+        else:
+            help = self.help
         optargfn = self.type
         if optargfn is None:
             parser.add_option(action='callback',
                               callback=self._optparse_bool_callback,
                               callback_args=(True,),
-                              help=self.help,
+                              help=help,
                               *option_strings)
             negation_strings = ['--%s' % self.get_negation_name()]
             parser.add_option(action='callback',
@@ -224,7 +232,7 @@
             parser.add_option(action='callback',
                               callback=self._optparse_callback,
                               type='string', metavar=self.argname.upper(),
-                              help=self.help,
+                              help=help,
                               default=OptionParser.DEFAULT_VALUE,
                               *option_strings)
 
@@ -250,7 +258,7 @@
         yield self.name, self.short_name(), argname, self.help
 
     def is_hidden(self, name):
-        return False
+        return self.hidden
 
 
 class ListOption(Option):

=== modified file 'bzrlib/tests/test_commands.py'
--- bzrlib/tests/test_commands.py	2009-03-23 14:59:43 +0000
+++ bzrlib/tests/test_commands.py	2009-04-03 20:05:25 +0000
@@ -23,6 +23,7 @@
     commands,
     config,
     errors,
+    option,
     tests,
     )
 from bzrlib.commands import display_command
@@ -60,6 +61,21 @@
         self.assertRaises(errors.BzrCommandError,
                           commands.run_bzr, ['log', u'--option\xb5'])
 
+    @staticmethod
+    def get_command(options):
+        c = commands.Command()
+        c.__doc__ = 'Bar'
+        c.takes_options = options
+        return c
+
+    def test_help_hidden(self):
+        c = self.get_command([option.Option('foo', hidden=True)])
+        self.assertNotContainsRe(c.get_help_text(), '--foo')
+
+    def test_help_not_hidden(self):
+        c = self.get_command([option.Option('foo', hidden=False)])
+        self.assertContainsRe(c.get_help_text(), '--foo')
+
 
 class TestGetAlias(tests.TestCase):
 

=== modified file 'bzrlib/tests/test_options.py'
--- bzrlib/tests/test_options.py	2009-03-23 14:59:43 +0000
+++ bzrlib/tests/test_options.py	2009-04-03 20:05:25 +0000
@@ -102,6 +102,10 @@
         self.assertRaises(errors.BzrCommandError, self.parse, options,
                           ['--no-number'])
 
+    def test_is_hidden(self):
+        self.assertTrue(option.Option('foo', hidden=True).is_hidden('foo'))
+        self.assertFalse(option.Option('foo', hidden=False).is_hidden('foo'))
+
     def test_registry_conversion(self):
         registry = bzrdir.BzrDirFormatRegistry()
         registry.register_metadir('one', 'RepositoryFormat7', 'one help')

